<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es_AR">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Seleccione uno o más dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkAudioController_wl</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Seleccione uno o más dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkCameraSingle</name>
    <message>
        <source>Remove window frame</source>
        <translation>Quitar el marco de la ventana</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Giro vertical</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Giro horizontal</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertir</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Gris</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Negro-y-blanco</translation>
    </message>
    <message>
        <source>Switch to Window</source>
        <translation>Cambiar a modo ventana</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Cambiar a pantalla completa</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Camera</source>
        <translation>Camara</translation>
    </message>
</context>
<context>
    <name>QvkCiscoFinishDialog</name>
    <message>
        <source>The setup was successful.</source>
        <translation>La instalación se realizó correctamente.</translation>
    </message>
    <message>
        <source>Close this window and start vokoscreenNG again.</source>
        <translation>Cierre esta ventana e inicie de nuevo vokoscreenNG.</translation>
    </message>
    <message>
        <source>Have fun with vokoscreenNG</source>
        <translation>Divertite con vokoscreenNG</translation>
    </message>
</context>
<context>
    <name>QvkDirDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialogo</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Administrador de archivos no valido</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Por favor, instale un administrador de archivos.</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs_wl</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Administrador de archivos no valido</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Por favor, instale un administrador de archivos.</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Advertencia</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>La grabación no ha empezado, no hay suficiente espacio en disco</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Se alcanzó el limite de espacio libre en disco</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Limite de espacio libre en el disco</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>La grabación ha parado, no hay suficiente espacio en disco</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>No filemanager found.</source>
        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
        <translation>Administrador de archivos no encontrado.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Por favor, instale un administrador de archivos.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Código fuente</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Sitio web</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Traducciones</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donar</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow_wl</name>
    <message>
        <source>Sourcecode</source>
        <translation>Código fuente</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Sitio web</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Traducciones</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donar</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Administrador de archivos no valido</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Por favor, instale un administrador de archivos.</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Seleccione uno o más dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher_wl</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Seleccione uno o más dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise_wl</name>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
</context>
<context>
    <name>QvkSnapshot</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Administrador de archivos no valido</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Por favor, instale un administrador de archivos.</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Camara</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Ampliación</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Camara</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Ampliación</translation>
    </message>
</context>
<context>
    <name>QvkWASAPIController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Seleccione uno o más dispositivos</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialogo</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Giro horizontal</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Giro vertical</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertir</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Gris</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Negro-y-blanco</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Quitar el marco de la ventana</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Opciones de Camara</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Ampliación</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Cuenta regresiva</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Tamaño de video:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Espacio libre en el disco:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informacón</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Tiempo de grabación</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Fotogramas</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Códec de video</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Códec de audio</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>No grabar el puntero del ratón</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Hora</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minuto</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Iniciar el cronometro</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Detener la grabacion después</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Horas</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minutos</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Segundos</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Ruta del vídeo</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Limite de espacio libre en el disco</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Mostrar en bandeja del sistema</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Segundo de espera antes de la grabación</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Buscar actualizaciones</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Disponible</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>No disponible</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Carpeta</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Camara</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertir</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Gris</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Reproducir la ultima grabación</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Abrir archivo</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimizar cuando comience la grabación</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Comienza minimizado</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Flip horizontal</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Giro vertical</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Negro-y-blanco</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Quitar el marco de la ventana</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Restablecer todas las configuraciones en el próximo inicio</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Copyright y licencia de imágenes</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Grabación</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Reproductor</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Log</translation>
    </message>
    <message>
        <source>Automatically</source>
        <translation>Automáticamente</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>Crear imágenes de pestañas </translation>
    </message>
    <message>
        <source>License information</source>
        <translation>Información sobre la licencia</translation>
    </message>
    <message>
        <source>ON</source>
        <translation>ON</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>OFF</translation>
    </message>
    <message>
        <source>Global keyboard shortcuts</source>
        <translation>Atajos de teclado globales</translation>
    </message>
    <message>
        <source>Assigned shortcut keys.</source>
        <translation>Teclas de acceso directo asignadas.</translation>
    </message>
    <message>
        <source>Keyboard shortcut not assigned or assigned more than once.</source>
        <translation>Atajo de teclado no asignado o asignado más de una vez.</translation>
    </message>
    <message>
        <source>If it shows assigned but does not work, it is being used by another program.</source>
        <translation>Si aparece asignado pero no funciona, es que está siendo utilizado por otro programa</translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation>Captura</translation>
    </message>
    <message>
        <source>Imagepath</source>
        <translation>Ruta de la imagen</translation>
    </message>
    <message>
        <source>Hide this window</source>
        <translation>Ocultar esta ventana</translation>
    </message>
    <message>
        <source>Seconds wait before recording</source>
        <translation>Segundo de espera antes de la grabación</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Ventana</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
</context>
<context>
    <name>formMainWindow_wl</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Copyright y licencia de imágenes</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>Crear imágenes de pestañas </translation>
    </message>
    <message>
        <source>License information</source>
        <translation>Información sobre la licencia</translation>
    </message>
    <message>
        <source>ON</source>
        <translation>ON</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>OFF</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Tiempo de grabación</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Tamaño de video:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Espacio libre en el disco:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informacón</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Ventana</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Códec de video</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Fotogramas</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Disponible</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>No disponible</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Carpeta</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>No grabar el puntero del ratón</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Códec de audio</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Ruta del vídeo</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Cuenta regresiva</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertir</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Gris</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Negro-y-blanco</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Cámara</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Giro vertical</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Giro horizontal</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Quitar el marco de la ventana</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Segundo de espera antes de la grabación</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Hide this window</source>
        <translation>Ocultar esta ventana</translation>
    </message>
    <message>
        <source>Seconds wait before recording</source>
        <translation>Segundo de espera antes de la grabación</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Copyright y licencia de imágenes</translation>
    </message>
</context>
<context>
    <name>playerGST</name>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
</context>
</TS>